import streamlit as st
from star_ratings import star_ratings

# Add some test code to play with the component while it's in development.
# During development, we can run this just as we would any other Streamlit
# app: `$ streamlit run my_component/example.py`

st.subheader("Component with constant args")

# Create an instance of our component with a constant `name` arg, and
# print its output value.
num_stars = st.slider("Select number of stars:", min_value=1, max_value=10, value=5)
ratings = star_ratings("", numStars=5)
st.markdown("You've given %s ratings!" % int(ratings if ratings else 0))

st.markdown("---")
st.subheader("Component with variable args")

# Create a second instance of our component whose `name` arg will vary
# based on a text_input widget.
#
# We use the special "key" argument to assign a fixed identity to this
# component instance. By default, when a component's arguments change,
# it is considered a new instance and will be re-mounted on the frontend
# and lose its current state. In this case, we want to vary the component's
# "name" argument without having it get recreated.
name_input = st.text_input("Enter a name", value="Streamlit")
new_ratings = star_ratings(name_input, key="foo")
st.markdown("You've given %s ratings!" % int(ratings if ratings else 0))
